@@ -72,7 +72,7 @@
 #define yynerrs         constexpYYnerrs
 
 /* First part of user prologue.  */
-#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 16 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
 
 
 #include "cppvalue.h"
@@ -91,7 +91,7 @@ int constexpYYerror(yyscan_t yyscanner, const char *s)
 }
 
 
-#line 95 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 95 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -1179,189 +1179,189 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* start: constant_expression  */
-#line 74 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 74 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
        {
          struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
          yyextra->resultValue = yyvsp[0]; return 0;
        }
-#line 1188 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1188 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 3: /* constant_expression: logical_or_expression  */
-#line 81 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 81 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1194 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1194 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 4: /* constant_expression: logical_or_expression TOK_QUESTIONMARK logical_or_expression TOK_COLON logical_or_expression  */
-#line 85 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 85 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      {
 		       bool c = (yyvsp[-4].isInt() ? ((long)yyvsp[-4] != 0) : ((double)yyvsp[-4] != 0.0));
 		       yyval = c ? yyvsp[-2] : yyvsp[0];
 	             }
-#line 1203 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1203 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 5: /* logical_or_expression: logical_and_expression  */
-#line 92 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 92 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1209 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 6: /* logical_or_expression: logical_or_expression TOK_OR logical_and_expression  */
-#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 94 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((long)yyvsp[-2] || (long)yyvsp[0]) );
 		       }
-#line 1217 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1217 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 7: /* logical_and_expression: inclusive_or_expression  */
-#line 100 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 100 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                         { yyval = yyvsp[0]; }
-#line 1223 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1223 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 8: /* logical_and_expression: logical_and_expression TOK_AND inclusive_or_expression  */
-#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 102 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                         {
 			  yyval = CPPValue( (long)((long)yyvsp[-2] && (long)yyvsp[0]) );
 			}
-#line 1231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 9: /* inclusive_or_expression: exclusive_or_expression  */
-#line 108 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 108 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1237 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1237 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 10: /* inclusive_or_expression: inclusive_or_expression TOK_BITWISEOR exclusive_or_expression  */
-#line 111 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 111 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] | (long)yyvsp[0] );
 			 }
-#line 1245 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1245 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 11: /* exclusive_or_expression: and_expression  */
-#line 117 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 117 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                          { yyval = yyvsp[0]; }
-#line 1251 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1251 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 12: /* exclusive_or_expression: exclusive_or_expression TOK_BITWISEXOR and_expression  */
-#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 119 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                          {
 			   yyval = CPPValue( (long)yyvsp[-2] ^ (long)yyvsp[0] );
 			 }
-#line 1259 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1259 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 13: /* and_expression: equality_expression  */
-#line 125 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 125 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                 { yyval = yyvsp[0]; }
-#line 1265 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1265 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 14: /* and_expression: and_expression TOK_AMPERSAND equality_expression  */
-#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 127 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                 {
 		  yyval = CPPValue( (long)yyvsp[-2] & (long)yyvsp[0] );
 		}
-#line 1273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1273 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 15: /* equality_expression: relational_expression  */
-#line 133 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 133 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1279 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1279 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 16: /* equality_expression: equality_expression TOK_EQUAL relational_expression  */
-#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 135 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      {
 		       yyval = CPPValue( (long)((double)yyvsp[-2] == (double)yyvsp[0]) );
 	             }
-#line 1287 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1287 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 17: /* equality_expression: equality_expression TOK_NOTEQUAL relational_expression  */
-#line 139 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 139 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      {
                        yyval = CPPValue( (long)((double)yyvsp[-2] != (double)yyvsp[0]) );
 		     }
-#line 1295 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1295 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 18: /* relational_expression: shift_expression  */
-#line 145 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 145 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        { yyval = yyvsp[0]; }
-#line 1301 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1301 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 19: /* relational_expression: relational_expression TOK_LESSTHAN shift_expression  */
-#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 147 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] < (double)yyvsp[0]) );
 		       }
-#line 1309 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1309 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 20: /* relational_expression: relational_expression TOK_GREATERTHAN shift_expression  */
-#line 151 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 151 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        {
                          yyval = CPPValue( (long)((double)yyvsp[-2] > (double)yyvsp[0]) );
 		       }
-#line 1317 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1317 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 21: /* relational_expression: relational_expression TOK_LESSTHANOREQUALTO shift_expression  */
-#line 156 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 156 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        {
 		         yyval = CPPValue( (long)((double)yyvsp[-2] <= (double)yyvsp[0]) );
 		       }
-#line 1325 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1325 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 22: /* relational_expression: relational_expression TOK_GREATERTHANOREQUALTO shift_expression  */
-#line 161 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 161 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                        {
 			 yyval = CPPValue( (long)((double)yyvsp[-2] >= (double)yyvsp[0]) );
 		       }
-#line 1333 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1333 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 23: /* shift_expression: additive_expression  */
-#line 167 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 167 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1339 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1339 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 24: /* shift_expression: shift_expression TOK_SHIFTLEFT additive_expression  */
-#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 169 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] << (long)yyvsp[0] );
 		  }
-#line 1347 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1347 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 25: /* shift_expression: shift_expression TOK_SHIFTRIGHT additive_expression  */
-#line 173 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 173 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   {
 		    yyval = CPPValue( (long)yyvsp[-2] >> (long)yyvsp[0] );
 		  }
-#line 1355 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1355 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 26: /* additive_expression: multiplicative_expression  */
-#line 179 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 179 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      { yyval = yyvsp[0]; }
-#line 1361 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1361 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 27: /* additive_expression: additive_expression TOK_PLUS multiplicative_expression  */
-#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 181 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      {
 		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 		       {
@@ -1372,11 +1372,11 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] + (long)yyvsp[0] );
 		       }
 		     }
-#line 1376 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1376 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 28: /* additive_expression: additive_expression TOK_MINUS multiplicative_expression  */
-#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 192 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                      {
 		       if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 		       {
@@ -1387,17 +1387,17 @@ yyreduce:
 		         yyval = CPPValue( (long)yyvsp[-2] - (long)yyvsp[0] );
 		       }
 		     }
-#line 1391 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1391 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 29: /* multiplicative_expression: unary_expression  */
-#line 205 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 205 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                            { yyval = yyvsp[0]; }
-#line 1397 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1397 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 30: /* multiplicative_expression: multiplicative_expression TOK_STAR unary_expression  */
-#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 207 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                            {
 			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 			     {
@@ -1408,11 +1408,11 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] * (long)yyvsp[0] );
 			     }
 			   }
-#line 1412 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1412 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 31: /* multiplicative_expression: multiplicative_expression TOK_DIVIDE unary_expression  */
-#line 218 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 218 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                            {
 			     if (!yyvsp[-2].isInt() || !yyvsp[0].isInt())
 			     {
@@ -1425,126 +1425,126 @@ yyreduce:
 			       yyval = CPPValue( (long)yyvsp[-2] / value );
 			     }
 			   }
-#line 1429 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1429 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 32: /* multiplicative_expression: multiplicative_expression TOK_MOD unary_expression  */
-#line 231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 231 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                            {
 			     long value = yyvsp[0];
 			     if (value==0) value=1;
 			     yyval = CPPValue( (long)yyvsp[-2] % value );
 			   }
-#line 1439 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1439 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 33: /* unary_expression: primary_expression  */
-#line 239 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 239 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   { yyval = yyvsp[0]; }
-#line 1445 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1445 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 34: /* unary_expression: TOK_PLUS unary_expression  */
-#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 241 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   { yyval = yyvsp[-1]; }
-#line 1451 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1451 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 35: /* unary_expression: TOK_MINUS unary_expression  */
-#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 243 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   {
 		    if (yyvsp[0].isInt())
                       yyval = CPPValue(-(long)yyvsp[0]);
                     else
 		      yyval = CPPValue(-(double)yyvsp[0]);
 		  }
-#line 1462 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1462 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 36: /* unary_expression: TOK_TILDE unary_expression  */
-#line 250 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 250 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   {
 		    yyval = CPPValue(~(long)yyvsp[0]);
 		  }
-#line 1470 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1470 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 37: /* unary_expression: TOK_NOT unary_expression  */
-#line 254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 254 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                   {
 		    yyval = CPPValue((long)!(long)yyvsp[0]);
 		  }
-#line 1478 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1478 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 38: /* primary_expression: constant  */
-#line 260 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 260 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                     { yyval = yyvsp[0]; }
-#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1484 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 39: /* primary_expression: TOK_LPAREN constant_expression TOK_RPAREN  */
-#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 262 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
                     { yyval = yyvsp[-1]; }
-#line 1490 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1490 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 40: /* constant: TOK_OCTALINT  */
-#line 266 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 266 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseOctal(yyextra->strToken);
+	    yyval = CPPValue::parseOctal(yyextra->strToken);
 	  }
-#line 1499 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1499 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 41: /* constant: TOK_DECIMALINT  */
-#line 271 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 271 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseDecimal(yyextra->strToken);
+	    yyval = CPPValue::parseDecimal(yyextra->strToken);
 	  }
-#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1508 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 42: /* constant: TOK_HEXADECIMALINT  */
-#line 276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 276 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseHexadecimal(yyextra->strToken);
+	    yyval = CPPValue::parseHexadecimal(yyextra->strToken);
 	  }
-#line 1517 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1517 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 43: /* constant: TOK_BINARYINT  */
-#line 281 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 281 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseBinary(yyextra->strToken);
+	    yyval = CPPValue::parseBinary(yyextra->strToken);
 	  }
-#line 1526 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1526 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 44: /* constant: TOK_CHARACTER  */
-#line 286 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 286 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseCharacter(yyextra->strToken);
+	    yyval = CPPValue::parseCharacter(yyextra->strToken);
 	  }
-#line 1535 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1535 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
   case 45: /* constant: TOK_FLOAT  */
-#line 291 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 291 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
           {
 	    struct constexpYY_state* yyextra = constexpYYget_extra(yyscanner);
-	    yyval = parseFloat(yyextra->strToken);
+	    yyval = CPPValue::parseFloat(yyextra->strToken);
 	  }
-#line 1544 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1544 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
     break;
 
 
-#line 1548 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/build/generated_src/ce_parse.cpp"
+#line 1548 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/build/generated_src/ce_parse.cpp"
 
       default: break;
     }
@@ -1737,5 +1737,5 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.5-1.i686/src/doxygen-1.9.5/src/constexp.y"
+#line 297 "/cygdrive/d/a/scallywag/doxygen/doxygen-1.9.6-1.x86_64/src/doxygen-1.9.6/src/constexp.y"
 
