@@ -26,8 +26,6 @@
 //
 //   2001/03/23 Jens Seidel (jensseidel@users.sourceforge.net)
 //    - fixed typos
-//    - changed trPageDocumentation() "Seitenbeschreibung" to
-//      "Zusätzliche Informationen"
 //    - removed old trGeneratedFrom()
 //    - changed "/*!" to "/*" (documentation is inherited from translator_en.h
 //      (INHERIT_DOCS = YES), there's no need to make changes twice)
@@ -127,13 +125,23 @@
 //    - Updated for "new since 1.8.0" version
 //    - Some small corrections
 //
+//   2016/03/15 Carsten Schumann (carsten at familie-schumann dot info)
+//    - Updated for "new since 1.8.4" version
+//
+//   2017/10/12 Arnd Weber (arnd dot weber at bafg dot de)
+//              Beatrix Konz
+//    - Updated for 1.8.13
+//    - Resynced trMemberDataDocumentation() and trFileMembers() to include the
+//      boolean switch OPTIMIZE_OUTPUT_FOR_C
+//    - Replaced "\t" by "    "
+//
 //   Todo:
 //    - see FIXME
 
 #ifndef TRANSLATOR_DE_H
 #define TRANSLATOR_DE_H
 
-class TranslatorGerman : public TranslatorAdapter_1_8_4
+class TranslatorGerman : public TranslatorAdapter_1_8_15
 {
   public:
 
@@ -156,6 +164,15 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       return "\\usepackage[ngerman]{babel}\n";
     }
 
+    virtual QCString trISOLang()
+    {
+      return "de";
+    }
+    virtual QCString getLanguageString()
+    {
+      return "0x407 German";
+    }
+
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
@@ -170,6 +187,10 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     virtual QCString trDetailedDescription()
     { return "Ausführliche Beschreibung"; }
 
+    /*! header that is used when the summary tag is missing inside the details tag */
+    virtual QCString trDetails()
+    { return "Details"; }
+
     /*! header that is put before the list of typedefs. */
     virtual QCString trMemberTypedefDocumentation()
     { return "Dokumentation der benutzerdefinierten Datentypen"; }
@@ -184,8 +205,15 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
-    { /* No difference if "OPTIMIZE_OUTPUT_FOR_C" is set! */
-      return "Dokumentation der Datenelemente";
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
+        return "Dokumentation der Felder";
+      }
+      else
+      {
+        return "Dokumentation der Datenelemente";
+      }
     }
 
     /*! this is the text of a link put after brief descriptions. */
@@ -211,9 +239,9 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! this is put at the author sections at the bottom of man pages.
      *  parameter s is name of the project name.
      */
-    virtual QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const QCString &s)
     { QCString result="Automatisch erzeugt von Doxygen";
-      if (s) result+=(QCString)" für "+s;
+      if (!s.isEmpty()) result+=" für "+s;
       result+=" aus dem Quellcode.";
       return result;
     }
@@ -245,7 +273,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! This is put above each page as a link to the list of annotated classes */
     virtual QCString trCompoundList()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datenstrukturen";
       }
@@ -262,7 +290,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! This is put above each page as a link to all members of compounds. */
     virtual QCString trCompoundMembers()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datenstruktur-Elemente";
       }
@@ -274,8 +302,16 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 
     /*! This is put above each page as a link to all members of files. */
     virtual QCString trFileMembers()
-    /* No difference if "OPTIMIZE_OUTPUT_FOR_C" is set! */
-    { return "Datei-Elemente"; }
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
+        return "Globale Elemente";
+      }
+      else
+      {
+        return "Datei-Elemente";
+      }
+    }
 
     /*! This is put above each page as a link to all related pages. */
     virtual QCString trRelatedPages()
@@ -291,8 +327,17 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 
     /*! This is an introduction to the class hierarchy. */
     virtual QCString trClassHierarchyDescription()
-    { return "Die Liste der Ableitungen ist -mit Einschränkungen- "
-             "alphabetisch sortiert:";
+    {
+      if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+        return "Hier folgt eine hierarchische Auflistung der "
+               "Entwurfseinheiten:";
+      }
+      else
+      {
+        return "Die Liste der Ableitungen ist -mit Einschränkungen- "
+               "alphabetisch sortiert:";
+      }
     }
 
     /*! This is an introduction to the list with all files. */
@@ -307,15 +352,19 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! This is an introduction to the annotated compound list. */
     virtual QCString trCompoundListDescription()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
-	return "Hier folgt die Aufzählung aller Datenstrukturen "
-	       "mit einer Kurzbeschreibung:";
+        return "Hier folgt die Aufzählung aller Datenstrukturen "
+               "mit einer Kurzbeschreibung:";
+      }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_SLICE))
+      {
+        return "Hier folgt die Aufzählung aller Klassen mit einer Kurzbeschreibung:";
       }
       else
       {
-	return "Hier folgt die Aufzählung aller Klassen, Strukturen, "
-	       "Varianten und Schnittstellen mit einer Kurzbeschreibung:";
+        return "Hier folgt die Aufzählung aller Klassen, Strukturen, "
+               "Varianten und Schnittstellen mit einer Kurzbeschreibung:";
       }
     }
 
@@ -327,7 +376,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       {
         result+="dokumentierten ";
       }
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="Strukturen und Varianten";
       }
@@ -338,7 +387,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       result+=" mit Verweisen auf ";
       if (!extractAll)
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="die Dokumentation zu jedem Element:";
         }
@@ -349,7 +398,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       }
       else
       {
-        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
         {
           result+="die zugehörigen Elemente:";
         }
@@ -366,7 +415,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     {
       QCString result="Hier folgt die Aufzählung aller ";
       if (!extractAll) result+="dokumentierten ";
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         result+="Funktionen, Variablen, Makros, Aufzählungen und Typdefinitionen";
       }
@@ -417,8 +466,8 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trCompoundIndex()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
-	return "Datenstruktur-Verzeichnis";
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+    return "Datenstruktur-Verzeichnis";
       else
         return "Klassen-Verzeichnis";
     }
@@ -440,10 +489,14 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trClassDocumentation()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datenstruktur-Dokumentation";
       }
+      else if (Config_getBool(OPTIMIZE_OUTPUT_VHDL))
+      {
+          return trDesignUnitDocumentation();
+      }
       else
       {
         return "Klassen-Dokumentation";
@@ -462,12 +515,6 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     virtual QCString trExampleDocumentation()
     { return "Dokumentation der Beispiele"; }
 
-    /*! This is used in LaTeX as the title of the chapter containing
-     *  the documentation of all related pages.
-     */
-    virtual QCString trPageDocumentation()
-    { return "Zusätzliche Informationen"; }
-
     /*! This is used in LaTeX as the title of the document */
     virtual QCString trReferenceManual()
     { return "Nachschlagewerk"; }
@@ -543,7 +590,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trCompounds()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datenstrukturen";
       }
@@ -556,24 +603,20 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! This is used in the standard footer of each page and indicates when
      *  the page was generated
      */
-    virtual QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const QCString &date,const QCString &projName)
     {
-      QCString result=(QCString)"Erzeugt am "+date;
-      if (projName) result+=(QCString)" für "+projName;
-      result+=(QCString)" von";
+      QCString result="Erzeugt am "+date;
+      if (!projName.isEmpty()) result+=" für "+projName;
+      result+=" von";
       return result;
     }
 
     /*! this text is put before a class diagram */
-    virtual QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const QCString &clName)
     {
-      return (QCString)"Klassendiagramm für "+clName+":";
+      return "Klassendiagramm für "+clName+":";
     }
 
-    /*! this text is generated when the \\internal command is used. */
-    virtual QCString trForInternalUseOnly()
-    { return "Nur für den internen Gebrauch."; }
-
     /*! this text is generated when the \\warning command is used. */
     virtual QCString trWarning()
     { return "Warnung"; }
@@ -644,11 +687,11 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    virtual QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const QCString &clName,
                                  ClassDef::CompoundType compType,
                                  bool isTemplate)
     {
-      QCString result=(QCString)clName+" ";
+      QCString result=clName+" ";
       if (isTemplate) result+="Template-";
       switch(compType)
       {
@@ -666,7 +709,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a file */
-    virtual QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const QCString &fileName)
     {
       QCString result=fileName;
       result+="-Dateireferenz";
@@ -674,7 +717,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a namespace */
-    virtual QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+="-Namensbereichsreferenz";
@@ -817,10 +860,11 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     { // single is true implies a single file
-      QCString result=(QCString)"Die Dokumentation für diese";
+      bool vhdlOpt = Config_getBool(OPTIMIZE_OUTPUT_VHDL);
+      QCString result="Die Dokumentation für diese";
       switch(compType)
       {
-        case ClassDef::Class:      result+=" Klasse"; break;
+        case ClassDef::Class:      result+=vhdlOpt?" Entwurfseinheiten":" Klasse"; break;
         case ClassDef::Struct:     result+=" Struktur"; break;
         case ClassDef::Union:      result+=" Variante"; break;
         case ClassDef::Interface:  result+=" Schnittstelle"; break;
@@ -881,15 +925,15 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    virtual QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const QCString &clName)
     {
-      return (QCString)"Zusammengehörigkeiten von "+clName+":";
+      return "Zusammengehörigkeiten von "+clName+":";
     }
 
     /*! this text is put before an include dependency graph */
-    virtual QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const QCString &fName)
     {
-      return (QCString)"Include-Abhängigkeitsdiagramm für "+fName+":";
+      return "Include-Abhängigkeitsdiagramm für "+fName+":";
     }
 
     /*! header that is put before the list of constructor/destructors. */
@@ -977,7 +1021,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 
     virtual QCString trPublicAttribs()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
       {
         return "Datenfelder";
       }
@@ -1136,7 +1180,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
         "Die Pfeile bedeuten:\n"
         "</p>\n"
         "<ul>\n"
-        "<li>Ein dunkelblauer Pfeil stellt eine öffentliche Vererbungsbeziehung "
+        "<li>Ein blauer Pfeil stellt eine öffentliche Vererbungsbeziehung "
         "zwischen zwei Klassen dar.</li>\n"
         "<li>Ein dunkelgrüner Pfeil stellt geschützte Vererbung dar.</li>\n"
         "<li>Ein dunkelroter Pfeil stellt private Vererbung dar.</li>\n"
@@ -1195,23 +1239,22 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
-      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      if (Config_getBool(OPTIMIZE_OUTPUT_FOR_C))
+      {
         return "Datenstrukturen";
+      }
       else
+      {
         return "Klassen";
+      }
     }
 
     /*! Used as the title of a Java package */
-    virtual QCString trPackage(const char *name)
+    virtual QCString trPackage(const QCString &name)
     {
-      return (QCString)"Paket "+name;
+      return "Paket "+name;
     }
 
-    /*! Title of the package index page */
-    virtual QCString trPackageList()
-    {
-      return "Paketliste";
-    }
 
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
@@ -1453,15 +1496,19 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     /*! Used as a heading for a list of Java class functions with package
      * scope.
      */
-    virtual QCString trPackageMembers()
+    virtual QCString trPackageFunctions()
     {
       return "Paketfunktionen";
     }
+    virtual QCString trPackageMembers()
+    {
+      return "Paketelemente";
+    }
 
     /*! Used as a heading for a list of static Java class functions with
      *  package scope.
      */
-    virtual QCString trStaticPackageMembers()
+    virtual QCString trStaticPackageFunctions()
     {
       return "Statische Paketfunktionen";
     }
@@ -1531,7 +1578,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       else
       {
         return "Es wurden <b>$num</b> Dokumente zu Ihrer Suchanfrage "
-	       "gefunden. Die besten Treffer werden zuerst angezeigt.";
+           "gefunden. Die besten Treffer werden zuerst angezeigt.";
       }
     }
     /*! This string is put before the list of matched words, for each search
@@ -1575,18 +1622,10 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     virtual QCString trDirectories()
     { return "Verzeichnisse"; }
 
-    /*! This returns a sentences that introduces the directory hierarchy.
-     *  and the fact that it is sorted alphabetically per level
-     */
-    virtual QCString trDirDescription()
-    { return "Diese Verzeichnishierarchie ist -mit Einschränkungen- "
-	     "alphabetisch sortiert:";
-    }
-
     /*! This returns the title of a directory page. The name of the
      *  directory is passed via \a dirName.
      */
-    virtual QCString trDirReference(const char *dirName)
+    virtual QCString trDirReference(const QCString &dirName)
     { QCString result=dirName; result+="-Verzeichnisreferenz"; return result; }
 
     /*! This returns the word directory with or without starting capital
@@ -1647,7 +1686,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 
     /*! This is an introduction to the annotated compound list (Fortran). */
     virtual QCString trCompoundListDescriptionFortran()
-	  { return "Hier folgen die Datentypen mit Kurzbeschreibungen:"; }
+      { return "Hier folgen die Datentypen mit Kurzbeschreibungen:"; }
 
     /*! This is an introduction to the page with all data types (Fortran). */
     virtual QCString trCompoundMembersDescriptionFortran(bool extractAll)
@@ -1714,11 +1753,11 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     }
 
     /*! used as the title of the HTML page of a module/type (Fortran) */
-    virtual QCString trCompoundReferenceFortran(const char *clName,
+    virtual QCString trCompoundReferenceFortran(const QCString &clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
-      QCString result=(QCString)clName;
+      QCString result=clName;
       result += "-";
       switch(compType)
       {
@@ -1736,7 +1775,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       return result;
     }
     /*! used as the title of the HTML page of a module (Fortran) */
-    virtual QCString trModuleReference(const char *namespaceName)
+    virtual QCString trModuleReference(const QCString &namespaceName)
     {
       QCString result=namespaceName;
       result+="-Modul-Referenz";
@@ -1788,7 +1827,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
         bool single)
     {
       // single is true implies a single file
-      QCString result=(QCString)"Die Dokumentation für ";
+      QCString result="Die Dokumentation für ";
       switch(compType)
       {
         case ClassDef::Class:      result+="dieses Modul"; break;
@@ -1840,7 +1879,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
 //////////////////////////////////////////////////////////////////////////
 
     /*! directory relation for \a name */
-    virtual QCString trDirRelation(const char *name)
+    virtual QCString trDirRelation(const QCString &name)
     {
       return "Bezug " + QCString(name);
     }
@@ -1877,18 +1916,18 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      *  table is shown. The heading for the first column mentions the
      *  source file that has a relation to another file.
      */
-    virtual QCString trFileIn(const char *name)
+    virtual QCString trFileIn(const QCString &name)
     {
-      return (QCString)"Datei in "+name;
+      return "Datei in "+name;
     }
 
     /*! when clicking a directory dependency label, a page with a
      *  table is shown. The heading for the second column mentions the
      *  destination file that is included.
      */
-    virtual QCString trIncludesFileIn(const char *name)
+    virtual QCString trIncludesFileIn(const QCString &name)
     {
-      return (QCString)"Include-Dateien in "+name;
+      return "Include-Dateien in "+name;
     }
 
     /** Compiles a date string.
@@ -1903,20 +1942,43 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
-                                bool includeTime)
+                                DateTimeType includeTime)
     {
       static const char *days[]   = { "Mon","Die","Mit","Don","Fre","Sam","Son" };
       static const char *months[] = { "Jan","Feb","Mär","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Dez" };
       QCString sdate;
-      sdate.sprintf("%s %s %d %d",days[dayOfWeek-1],months[month-1],day,year);
-      if (includeTime)
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Date)
+      {
+        sdate.sprintf("%s %s %d %d",days[dayOfWeek-1],months[month-1],day,year);
+      }
+      if (includeTime == DateTimeType::DateTime) sdate += " ";
+      if (includeTime == DateTimeType::DateTime || includeTime == DateTimeType::Time)
       {
         QCString stime;
-        stime.sprintf(" %.2d:%.2d:%.2d",hour,minutes,seconds);
+        stime.sprintf("%.2d:%.2d:%.2d",hour,minutes,seconds);
         sdate+=stime;
       }
       return sdate;
     }
+    virtual QCString trDayOfWeek(int dayOfWeek, bool, bool full)
+    {
+      static const char *days_short[]   = { "Mo", "Di", "Mi", "Do", "Fr", "Sa", "So" };
+      static const char *days_full[]    = { "Montag", "Dienstag", "Mittwoch", "Donnerstag", "Freitag", "Samstag", "Sonntag" };
+      QCString text  = full? days_full[dayOfWeek-1] : days_short[dayOfWeek-1];
+      return text;
+    }
+    virtual QCString trMonth(int month, bool, bool full)
+    {
+      static const char *months_short[] = { "Jan", "Feb", "Mrz", "Apr", "Mai", "Jun", "Jul", "Aug", "Sep", "Okt", "Nov", "Dez" };
+      static const char *months_full[]  = { "Januar", "Februar", "März", "April", "Mai", "Juni", "Juli", "August", "September", "Oktober", "November", "Dezember" };
+      QCString text  = full? months_full[month-1] : months_short[month-1];
+      return text;
+    }
+    virtual QCString trDayPeriod(int period)
+    {
+      static const char *dayPeriod[] = { "AM", "PM" };
+      return dayPeriod[period];
+    }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 1.7.5
@@ -1931,7 +1993,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     { return "Copyright"; }
 
     /*! Header for the graph showing the directory dependencies */
-    virtual QCString trDirDepGraph(const char *name)
+    virtual QCString trDirDepGraph(const QCString &name)
     { return QCString("Diagramm der Verzeichnisabhängigkeiten für ")+name+":"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1954,19 +2016,19 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
     virtual QCString trEnumGeneratedFromFiles(bool single)
     { QCString result = "Die Dokumentation für diesen enum wurde aus ";
       if (single)
-		result += "der folgenden Datei";
-	  else
-		result += "den folgenden Dateien";
+        result += "der folgenden Datei";
+      else
+        result += "den folgenden Dateien";
       result+=" generiert:";
       return result;
     }
 
     /*! Header of a Java enum page (Java enums are represented as classes). */
-    virtual QCString trEnumReference(const char *name)
+    virtual QCString trEnumReference(const QCString &name)
     { return QCString(name)+" Enum-Referenz"; }
 
     /*! Used for a section containing inherited members */
-    virtual QCString trInheritedFrom(const char *members,const char *what)
+    virtual QCString trInheritedFrom(const QCString &members,const QCString &what)
     { return QCString(members)+" geerbt von "+what; }
 
     /*! Header of the sections with inherited members specific for the
@@ -1995,7 +2057,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trProvidedByCategory()
     {
-      return "Bestandteil der Kategorie @1.";
+      return "Bestandteil der Kategorie @0.";
     }
 
     /*! Used in a method of an Objective-C category that extends a class.
@@ -2004,7 +2066,7 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
      */
     virtual QCString trExtendsClass()
     {
-      return "Erweitert Klasse @1.";
+      return "Erweitert Klasse @0.";
     }
 
     /*! Used as the header of a list of class methods in Objective-C.
@@ -2030,15 +2092,187 @@ class TranslatorGerman : public TranslatorAdapter_1_8_4
       return "Methodendokumentation";
     }
 
-    /*! Used as the title of the design overview picture created for the
-     *  VHDL output.
-     */
-    virtual QCString trDesignOverview()
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.4
+//////////////////////////////////////////////////////////////////////////
+
+    /** old style UNO IDL services: implemented interfaces */
+    virtual QCString trInterfaces()
+    { return "Exportierte Interfaces"; }
+
+    /** old style UNO IDL services: inherited services */
+    virtual QCString trServices()
+    { return "Eingebundene Dienste"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroups()
+    { return "Konstante Gruppen"; }
+
+    /** UNO IDL constant groups */
+    virtual QCString trConstantGroupReference(const QCString &namespaceName)
     {
-      return "Übersicht";
+      QCString result=namespaceName;
+      result+=" Konstantengruppen-Referenz";
+      return result;
+    }
+
+    /** UNO IDL service page title */
+    virtual QCString trServiceReference(const QCString &sName)
+    {
+      QCString result=sName;
+      result+=" Dienstreferenz";
+      return result;
+    }
+
+    /** UNO IDL singleton page title */
+    virtual QCString trSingletonReference(const QCString &sName)
+    {
+      QCString result=sName;
+      result+=" Singleton-Referenz";
+      return result;
+    }
+
+    /** UNO IDL service page */
+    virtual QCString trServiceGeneratedFromFiles(bool single)
+    {
+      QCString result="Die Dokumentation für diesen Dienst "
+                                "wurde generiert aus ";
+      if (single) result+="folgender Datei: "; else result+="folgenden Dateien: ";
+      return result;
+    }
+
+    /** UNO IDL singleton page */
+    virtual QCString trSingletonGeneratedFromFiles(bool single)
+    {
+      QCString result="Die Dokumentation für diesen Singleton wurde generiert aus ";
+      if (single) result+="folgender Datei:"; else result+="folgenden Dateien:";
+      return result;
     }
 
 //////////////////////////////////////////////////////////////////////////
+// new since 1.8.15
+//////////////////////////////////////////////////////////////////////////
+
+    /** VHDL design unit hierarchy */
+    virtual QCString trDesignUnitHierarchy()
+    { return "Entwurfseinheiten-Hierarchie"; }
+    /** VHDL design unit list */
+    virtual QCString trDesignUnitList()
+    { return "Auflistung der Entwurfseinheiten"; }
+    /** VHDL design unit members */
+    virtual QCString trDesignUnitMembers()
+    { return "Entwurfseinheiten-Elemente"; }
+    /** VHDL design unit list description */
+    virtual QCString trDesignUnitListDescription()
+    {
+        return "Hier folgt die Aufzählung aller Entwurfseinheiten und deren "
+               "Elemente mit einer Kurzbeschreibung:";
+    }
+    /** VHDL design unit index */
+    virtual QCString trDesignUnitIndex()
+    { return "Entwurfseinheiten-Verzeichnis"; }
+    /** VHDL design units */
+    virtual QCString trDesignUnits()
+    { return "Entwurfseinheiten"; }
+    /** VHDL functions/procedures/processes */
+    virtual QCString trFunctionAndProc()
+    { return "Funktionen/Prozeduren/Prozesse"; }
+    /** VHDL type */
+    virtual QCString trVhdlType(uint64 type,bool single)
+    {
+      switch(type)
+      {
+        case VhdlDocGen::LIBRARY:
+          if (single) return "Bibliothek";
+          else        return "Bibliotheken";
+        case VhdlDocGen::PACKAGE:
+          if (single) return "Paket";
+          else        return "Pakete";
+        case VhdlDocGen::SIGNAL:
+          if (single) return "Signal";
+          else        return "Signale";
+        case VhdlDocGen::COMPONENT:
+          if (single) return "Komponente";
+          else        return "Komponenten";
+        case VhdlDocGen::CONSTANT:
+          if (single) return "Konstante";
+          else        return "Konstanten";
+        case VhdlDocGen::ENTITY:
+          if (single) return "Entwurfseinheit";
+          else        return "Entwurfseinheiten";
+        case VhdlDocGen::TYPE:
+          if (single) return "Typ";
+          else        return "Typen";
+        case VhdlDocGen::SUBTYPE:
+          if (single) return "Subtyp";
+          else        return "Subtypen";
+        case VhdlDocGen::FUNCTION:
+          if (single) return "Funktion";
+          else        return "Funktionen";
+        case VhdlDocGen::RECORD:
+          if (single) return "Datenstruktur";
+          else        return "Datenstrukturen";
+        case VhdlDocGen::PROCEDURE:
+          if (single) return "Prozedur";
+          else        return "Prozeduren";
+        case VhdlDocGen::ARCHITECTURE:
+          if (single) return "Architektur";
+          else        return "Architekturen";
+        case VhdlDocGen::ATTRIBUTE:
+          if (single) return "Attribut";
+          else        return "Attribute";
+        case VhdlDocGen::PROCESS:
+          if (single) return "Prozess";
+          else        return "Prozesse";
+        case VhdlDocGen::PORT:
+          if (single) return "Schnittstelle";
+          else        return "Schnittstellen";
+        case VhdlDocGen::USE:
+          if (single) return "Use Klausel";
+          else        return "Use Klauseln";
+        case VhdlDocGen::GENERIC:
+          if (single) return "Parameter";
+          else        return "Parameter";
+        case VhdlDocGen::PACKAGE_BODY:
+          return "Paketkörper";
+        case VhdlDocGen::UNITS:
+          return "Einheiten";
+        case VhdlDocGen::SHAREDVARIABLE:
+          if (single) return "Geteilte Variable";
+          else        return "Geteilte Variablen";
+        case VhdlDocGen::VFILE:
+          if (single) return "Datei";
+          else        return "Dateien";
+        case VhdlDocGen::GROUP:
+          if (single) return "Gruppe";
+          else        return "Gruppen";
+        case VhdlDocGen::INSTANTIATION:
+          if (single) return "Instanziierung";
+          else        return "Instanziierungen";
+        case VhdlDocGen::ALIAS:
+          if (single) return "Alias";
+          else        return "Aliase";
+        case VhdlDocGen::CONFIG:
+          if (single) return "Konfiguration";
+          else        return "Konfigurationen";
+        case VhdlDocGen::MISCELLANEOUS:
+          return "Verschiedenes";
+        case VhdlDocGen::UCF_CONST:
+          return "Constraints";
+        default:
+          return "Klasse";
+      }
+    }
+    virtual QCString trCustomReference(const QCString &name)
+    { return QCString(name)+"-Referenz"; }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.8.19
+//////////////////////////////////////////////////////////////////////////
+
+    /** VHDL design unit documentation */
+    virtual QCString trDesignUnitDocumentation()
+    { return "Entwurfseinheiten-Dokumentation"; }
 
 };
 
